=======
nlon-py
=======


.. image:: https://img.shields.io/pypi/v/nlon-py.svg
        :target: https://pypi.python.org/pypi/nlon-py

.. image:: https://travis-ci.com/Jianwen-Xu/NLoN-PY.svg
        :target: https://travis-ci.com/Jianwen-Xu/nlon-py

.. image:: https://readthedocs.org/projects/nlon-py/badge/?version=latest
        :target: https://nlon-py.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python package for identifying text containing natural language (or not) using machine learning.


* Free software: MIT license
* Documentation: https://nlon-py.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
